"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""

import re  # noqa: F401

from pyasoc import api

# python 2 and python 3 compatibility library
from pyasoc.api_client import ApiClient
from pyasoc.models import (
    CommonModelsASMModelsApplicationCreateModel,
    CommonModelsASMModelsApplicationModel,
)


class AppsApi:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def apps_attach_policy_by_id_and_policyid(self, id, policy_id, parameters, **kwargs):
        """Associate a policy with an application or update association parameters

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_attach_policy_by_id_and_policyid(id, policy_id, parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param str policy_id: Policy ID (required)
        :param list[NameValuePair] parameters: Policy parameters (required)
        :return: PolicyAssociation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_attach_policy_by_id_and_policyid_with_http_info(
                id, policy_id, parameters, **kwargs
            )
        else:
            (data) = self.apps_attach_policy_by_id_and_policyid_with_http_info(
                id, policy_id, parameters, **kwargs
            )
            return data

    def apps_attach_policy_by_id_and_policyid_with_http_info(
        self, id, policy_id, parameters, **kwargs
    ):
        """Associate a policy with an application or update association parameters

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_attach_policy_by_id_and_policyid_with_http_info(id, policy_id, parameters, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param str policy_id: Policy ID (required)
        :param list[NameValuePair] parameters: Policy parameters (required)
        :return: PolicyAssociation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "policy_id", "parameters"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apps_attach_policy_by_id_and_policyid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_attach_policy_by_id_and_policyid`"
            )
        # verify the required parameter 'policy_id' is set
        if self.api_client.client_side_validation and (
            "policy_id" not in params or params["policy_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `policy_id` when calling `apps_attach_policy_by_id_and_policyid`"
            )
        # verify the required parameter 'parameters' is set
        if self.api_client.client_side_validation and (
            "parameters" not in params or params["parameters"] is None
        ):
            raise ValueError(
                "Missing the required parameter `parameters` when calling `apps_attach_policy_by_id_and_policyid`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]
        if "policy_id" in params:
            path_params["policyId"] = params["policy_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "parameters" in params:
            body_params = params["parameters"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Apps/{id}/Policy/{policyId}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PolicyAssociation",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_correlation_groups_as_page_by_id(self, id, **kwargs):
        """apps_correlation_groups_as_page_by_id

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_correlation_groups_as_page_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str apply_policies:
        :param list[str] select_policy_ids:
        :param str locale:
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultUtilitiesSharedModelsCorrelationGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_correlation_groups_as_page_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.apps_correlation_groups_as_page_by_id_with_http_info(id, **kwargs)
            return data

    def apps_correlation_groups_as_page_by_id_with_http_info(self, id, **kwargs):
        """apps_correlation_groups_as_page_by_id

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_correlation_groups_as_page_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: (required)
        :param str apply_policies:
        :param list[str] select_policy_ids:
        :param str locale:
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultUtilitiesSharedModelsCorrelationGroupModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "id",
            "apply_policies",
            "select_policy_ids",
            "locale",
            "top",
            "skip",
            "filter",
            "select",
            "orderby",
            "expand",
            "inlinecount",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apps_correlation_groups_as_page_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_correlation_groups_as_page_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []
        if "apply_policies" in params:
            query_params.append(("applyPolicies", params["apply_policies"]))
        if "select_policy_ids" in params:
            query_params.append(("selectPolicyIds", params["select_policy_ids"]))
            collection_formats["selectPolicyIds"] = "multi"
        if "locale" in params:
            query_params.append(("locale", params["locale"]))
        if "top" in params:
            query_params.append(("$top", params["top"]))
        if "skip" in params:
            query_params.append(("$skip", params["skip"]))
        if "filter" in params:
            query_params.append(("$filter", params["filter"]))
        if "select" in params:
            query_params.append(("$select", params["select"]))
        if "orderby" in params:
            query_params.append(("$orderby", params["orderby"]))
        if "expand" in params:
            query_params.append(("$expand", params["expand"]))
        if "inlinecount" in params:
            query_params.append(("$inlinecount", params["inlinecount"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Apps/{id}/CorrelationGroupsAsPage",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SystemWebHttpODataPageResultUtilitiesSharedModelsCorrelationGroupModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_count(self, **kwargs):
        """Get applications count according to filter

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_count(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserSiteCommonModelsCountModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_count_with_http_info(**kwargs)
        else:
            (data) = self.apps_count_with_http_info(**kwargs)
            return data

    def apps_count_with_http_info(self, **kwargs):
        """Get applications count according to filter

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_count_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :return: UserSiteCommonModelsCountModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = []
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_count" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps/Count",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsCountModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_create_app(
        self, model: CommonModelsASMModelsApplicationCreateModel, **kwargs
    ) -> CommonModelsASMModelsApplicationModel:
        """Create an application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_create_app(model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CommonModelsASMModelsApplicationCreateModel model:  (required)
        :return: CommonModelsASMModelsApplicationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_create_app_with_http_info(model, **kwargs)
        else:
            (data) = self.apps_create_app_with_http_info(model, **kwargs)
            return data

    def apps_create_app_with_http_info(self, model, **kwargs):
        """Create an application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_create_app_with_http_info(model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param CommonModelsASMModelsApplicationCreateModel model:  (required)
        :return: CommonModelsASMModelsApplicationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["model"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_create_app" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'model' is set
        if self.api_client.client_side_validation and (
            "model" not in params or params["model"] is None
        ):
            raise ValueError(
                "Missing the required parameter `model` when calling `apps_create_app`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "model" in params:
            body_params = params["model"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CommonModelsASMModelsApplicationModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_delete_app_by_id(self, id, **kwargs):
        """Delete application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_delete_app_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: application id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_delete_app_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.apps_delete_app_by_id_with_http_info(id, **kwargs)
            return data

    def apps_delete_app_by_id_with_http_info(self, id, **kwargs):
        """Delete application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_delete_app_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: application id (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apps_delete_app_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_delete_app_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps/{id}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_delete_policy_association_by_id_and_policyid(self, id, policy_id, **kwargs):
        """Disassociate a policy from an application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_delete_policy_association_by_id_and_policyid(id, policy_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param str policy_id: Policy ID (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_delete_policy_association_by_id_and_policyid_with_http_info(
                id, policy_id, **kwargs
            )
        else:
            (data) = self.apps_delete_policy_association_by_id_and_policyid_with_http_info(
                id, policy_id, **kwargs
            )
            return data

    def apps_delete_policy_association_by_id_and_policyid_with_http_info(
        self, id, policy_id, **kwargs
    ):
        """Disassociate a policy from an application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_delete_policy_association_by_id_and_policyid_with_http_info(id, policy_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param str policy_id: Policy ID (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "policy_id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apps_delete_policy_association_by_id_and_policyid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_delete_policy_association_by_id_and_policyid`"
            )
        # verify the required parameter 'policy_id' is set
        if self.api_client.client_side_validation and (
            "policy_id" not in params or params["policy_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `policy_id` when calling `apps_delete_policy_association_by_id_and_policyid`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]
        if "policy_id" in params:
            path_params["policyId"] = params["policy_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Apps/{id}/Policy/{policyId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_get_app_by_id(self, id, **kwargs) -> CommonModelsASMModelsApplicationModel:
        """Get an application by ID

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_get_app_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :return: CommonModelsASMModelsApplicationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_get_app_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.apps_get_app_by_id_with_http_info(id, **kwargs)
            return data

    def apps_get_app_by_id_with_http_info(self, id, **kwargs):
        """Get an application by ID

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_get_app_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :return: CommonModelsASMModelsApplicationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_get_app_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_get_app_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps/{id}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CommonModelsASMModelsApplicationModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_get_app_policies_by_id(self, id, **kwargs):
        """Get policies associated with this application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_get_app_policies_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application Id (required)
        :return: list[PolicyAssociation]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_get_app_policies_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.apps_get_app_policies_by_id_with_http_info(id, **kwargs)
            return data

    def apps_get_app_policies_by_id_with_http_info(self, id, **kwargs):
        """Get policies associated with this application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_get_app_policies_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application Id (required)
        :return: list[PolicyAssociation]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apps_get_app_policies_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_get_app_policies_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Apps/{id}/Policy",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[PolicyAssociation]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_get_apps(self, **kwargs):
        """Get all the apps in the current context

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_get_apps(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :return: list[CommonModelsASMModelsApplicationModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_get_apps_with_http_info(**kwargs)
        else:
            (data) = self.apps_get_apps_with_http_info(**kwargs)
            return data

    def apps_get_apps_with_http_info(self, **kwargs):
        """Get all the apps in the current context

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_get_apps_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :return: list[CommonModelsASMModelsApplicationModel]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "top",
            "skip",
            "filter",
            "select",
            "orderby",
            "expand",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_get_apps" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "top" in params:
            query_params.append(("$top", params["top"]))
        if "skip" in params:
            query_params.append(("$skip", params["skip"]))
        if "filter" in params:
            query_params.append(("$filter", params["filter"]))
        if "select" in params:
            query_params.append(("$select", params["select"]))
        if "orderby" in params:
            query_params.append(("$orderby", params["orderby"]))
        if "expand" in params:
            query_params.append(("$expand", params["expand"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[CommonModelsASMModelsApplicationModel]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_get_apps_page(self, **kwargs):
        """Get all the apps in the current context

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_get_apps_page(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultCommonModelsASMModelsApplicationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_get_apps_page_with_http_info(**kwargs)
        else:
            (data) = self.apps_get_apps_page_with_http_info(**kwargs)
            return data

    def apps_get_apps_page_with_http_info(self, **kwargs):
        """Get all the apps in the current context

        OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_get_apps_page_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :param str inlinecount: Specifies that the response to the request MUST include the count of the number of entities in the collection of entities.
        :return: SystemWebHttpODataPageResultCommonModelsASMModelsApplicationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "top",
            "skip",
            "filter",
            "select",
            "orderby",
            "expand",
            "inlinecount",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_get_apps_page" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "top" in params:
            query_params.append(("$top", params["top"]))
        if "skip" in params:
            query_params.append(("$skip", params["skip"]))
        if "filter" in params:
            query_params.append(("$filter", params["filter"]))
        if "select" in params:
            query_params.append(("$select", params["select"]))
        if "orderby" in params:
            query_params.append(("$orderby", params["orderby"]))
        if "expand" in params:
            query_params.append(("$expand", params["expand"]))
        if "inlinecount" in params:
            query_params.append(("$inlinecount", params["inlinecount"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps/GetAsPage",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="SystemWebHttpODataPageResultCommonModelsASMModelsApplicationModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_group_count(self, grouping, **kwargs):
        """Get applications group count according to filter

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_group_count(grouping, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str grouping: (required)
        :return: UserSiteCommonModelsGroupCountModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_group_count_with_http_info(grouping, **kwargs)
        else:
            (data) = self.apps_group_count_with_http_info(grouping, **kwargs)
            return data

    def apps_group_count_with_http_info(self, grouping, **kwargs):
        """Get applications group count according to filter

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_group_count_with_http_info(grouping, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str grouping: (required)
        :return: UserSiteCommonModelsGroupCountModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["grouping"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_group_count" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'grouping' is set
        if self.api_client.client_side_validation and (
            "grouping" not in params or params["grouping"] is None
        ):
            raise ValueError(
                "Missing the required parameter `grouping` when calling `apps_group_count`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []
        if "grouping" in params:
            query_params.append(("grouping", params["grouping"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps/GroupCount",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsGroupCountModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_import_file(self, file_to_upload, asset_group_id, **kwargs):
        """Import Apps

        Import Apps from uploaded file to application specified with id.<br />              Includes file format validation.<br />              The expected Content-Type of the request is multipart/form-data. The request should contain a single file parameter named \"fileToUpload\".
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_import_file(file_to_upload, asset_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file_to_upload: (required)
        :param str asset_group_id: (required)
        :param str file_name: If provided, this parameter will override the name of the uploaded file, including its extension(CSV).
        :return: ImportAppResultModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_import_file_with_http_info(file_to_upload, asset_group_id, **kwargs)
        else:
            (data) = self.apps_import_file_with_http_info(file_to_upload, asset_group_id, **kwargs)
            return data

    def apps_import_file_with_http_info(self, file_to_upload, asset_group_id, **kwargs):
        """Import Apps

        Import Apps from uploaded file to application specified with id.<br />              Includes file format validation.<br />              The expected Content-Type of the request is multipart/form-data. The request should contain a single file parameter named \"fileToUpload\".
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_import_file_with_http_info(file_to_upload, asset_group_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param file file_to_upload: (required)
        :param str asset_group_id: (required)
        :param str file_name: If provided, this parameter will override the name of the uploaded file, including its extension(CSV).
        :return: ImportAppResultModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["file_to_upload", "asset_group_id", "file_name"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_import_file" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'file_to_upload' is set
        if self.api_client.client_side_validation and (
            "file_to_upload" not in params or params["file_to_upload"] is None
        ):
            raise ValueError(
                "Missing the required parameter `file_to_upload` when calling `apps_import_file`"
            )
        # verify the required parameter 'asset_group_id' is set
        if self.api_client.client_side_validation and (
            "asset_group_id" not in params or params["asset_group_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `asset_group_id` when calling `apps_import_file`"
            )

        if self.api_client.client_side_validation and (
            "file_name" in params and len(params["file_name"]) > 2048
        ):
            raise ValueError(
                "Invalid value for parameter `file_name` when calling `apps_import_file`, length must be less than or equal to `2048`"
            )
        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}
        if "file_to_upload" in params:
            local_var_files["fileToUpload"] = params["file_to_upload"]
        if "file_name" in params:
            form_params.append(("fileName", params["file_name"]))
        if "asset_group_id" in params:
            form_params.append(("assetGroupId", params["asset_group_id"]))

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["multipart/form-data"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps/ImportFile",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="ImportAppResultModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_license_by_id(self, id, **kwargs):
        """Get application license

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_license_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param str technology: Requested technology
        :return: CommonModelsASMModelsAppLicense
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_license_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.apps_license_by_id_with_http_info(id, **kwargs)
            return data

    def apps_license_by_id_with_http_info(self, id, **kwargs):
        """Get application license

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_license_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param str technology: Requested technology
        :return: CommonModelsASMModelsAppLicense
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "technology"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_license_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_license_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []
        if "technology" in params:
            query_params.append(("technology", params["technology"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Apps/{id}/License",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CommonModelsASMModelsAppLicense",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_reset_by_id(self, id, reset_options, **kwargs):
        """Reset application

        Reset options (set in the request body):<br /><b>DeleteIssues:</b>  Delete all the Application’s issues.<br /><b>DeleteScans:</b>  Delete all the Application’s scans.<br /><b>DeleteChartsData:</b> Delete all the data related to the application from the Dashboard charts. (This will affect charts from previous dates too. The application will be removed from all graphs that contain application counts.)<br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_reset_by_id(id, reset_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application id (required)
        :param ApplicationResetModel reset_options: Determine which data will be cleared (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_reset_by_id_with_http_info(id, reset_options, **kwargs)
        else:
            (data) = self.apps_reset_by_id_with_http_info(id, reset_options, **kwargs)
            return data

    def apps_reset_by_id_with_http_info(self, id, reset_options, **kwargs):
        """Reset application

        Reset options (set in the request body):<br /><b>DeleteIssues:</b>  Delete all the Application’s issues.<br /><b>DeleteScans:</b>  Delete all the Application’s scans.<br /><b>DeleteChartsData:</b> Delete all the data related to the application from the Dashboard charts. (This will affect charts from previous dates too. The application will be removed from all graphs that contain application counts.)<br />
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_reset_by_id_with_http_info(id, reset_options, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application id (required)
        :param ApplicationResetModel reset_options: Determine which data will be cleared (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "reset_options"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_reset_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError("Missing the required parameter `id` when calling `apps_reset_by_id`")
        # verify the required parameter 'reset_options' is set
        if self.api_client.client_side_validation and (
            "reset_options" not in params or params["reset_options"] is None
        ):
            raise ValueError(
                "Missing the required parameter `reset_options` when calling `apps_reset_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "reset_options" in params:
            body_params = params["reset_options"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Apps/{id}/Reset",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_scans_by_id(self, id, **kwargs):
        """Get scans under the given application

        This API is obsolete. Please refer to API: GET /api/v2/Scans/GetAsPageMin</br>OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_scans_by_id(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :return: list[AppScanSaaSModelsV2Scan1]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_scans_by_id_with_http_info(id, **kwargs)
        else:
            (data) = self.apps_scans_by_id_with_http_info(id, **kwargs)
            return data

    def apps_scans_by_id_with_http_info(self, id, **kwargs):
        """Get scans under the given application

        This API is obsolete. Please refer to API: GET /api/v2/Scans/GetAsPageMin</br>OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_scans_by_id_with_http_info(id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :return: list[AppScanSaaSModelsV2Scan1]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "id",
            "top",
            "skip",
            "filter",
            "select",
            "orderby",
            "expand",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'" " to method apps_scans_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError("Missing the required parameter `id` when calling `apps_scans_by_id`")

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []
        if "top" in params:
            query_params.append(("$top", params["top"]))
        if "skip" in params:
            query_params.append(("$skip", params["skip"]))
        if "filter" in params:
            query_params.append(("$filter", params["filter"]))
        if "select" in params:
            query_params.append(("$select", params["select"]))
        if "orderby" in params:
            query_params.append(("$orderby", params["orderby"]))
        if "expand" in params:
            query_params.append(("$expand", params["expand"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Apps/{id}/Scans",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[AppScanSaaSModelsV2Scan1]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_update_app_by_id(self, id, model, **kwargs):
        """Update application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_update_app_by_id(id, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application Id (required)
        :param CommonModelsASMModelsApplicationUpdateModel model:  (required)
        :return: CommonModelsASMModelsApplicationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_update_app_by_id_with_http_info(id, model, **kwargs)
        else:
            (data) = self.apps_update_app_by_id_with_http_info(id, model, **kwargs)
            return data

    def apps_update_app_by_id_with_http_info(self, id, model, **kwargs):
        """Update application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_update_app_by_id_with_http_info(id, model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application Id (required)
        :param CommonModelsASMModelsApplicationUpdateModel model:  (required)
        :return: CommonModelsASMModelsApplicationModel
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "model"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apps_update_app_by_id" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_update_app_by_id`"
            )
        # verify the required parameter 'model' is set
        if self.api_client.client_side_validation and (
            "model" not in params or params["model"] is None
        ):
            raise ValueError(
                "Missing the required parameter `model` when calling `apps_update_app_by_id`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "model" in params:
            body_params = params["model"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/V2/Apps/{id}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="CommonModelsASMModelsApplicationModel",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def apps_update_policy_by_id_and_policyid(self, id, policy_id, configuration_model, **kwargs):
        """Update the policy parameters for this application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_update_policy_by_id_and_policyid(id, policy_id, configuration_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param str policy_id: Policy ID (required)
        :param PolicyConfiguration configuration_model: Policy configuration for this application (required)
        :return: PolicyAssociation
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.apps_update_policy_by_id_and_policyid_with_http_info(
                id, policy_id, configuration_model, **kwargs
            )
        else:
            (data) = self.apps_update_policy_by_id_and_policyid_with_http_info(
                id, policy_id, configuration_model, **kwargs
            )
            return data

    def apps_update_policy_by_id_and_policyid_with_http_info(
        self, id, policy_id, configuration_model, **kwargs
    ):
        """Update the policy parameters for this application

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.apps_update_policy_by_id_and_policyid_with_http_info(id, policy_id, configuration_model, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str id: Application ID (required)
        :param str policy_id: Policy ID (required)
        :param PolicyConfiguration configuration_model: Policy configuration for this application (required)
        :return: PolicyAssociation
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["id", "policy_id", "configuration_model"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method apps_update_policy_by_id_and_policyid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'id' is set
        if self.api_client.client_side_validation and ("id" not in params or params["id"] is None):
            raise ValueError(
                "Missing the required parameter `id` when calling `apps_update_policy_by_id_and_policyid`"
            )
        # verify the required parameter 'policy_id' is set
        if self.api_client.client_side_validation and (
            "policy_id" not in params or params["policy_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `policy_id` when calling `apps_update_policy_by_id_and_policyid`"
            )
        # verify the required parameter 'configuration_model' is set
        if self.api_client.client_side_validation and (
            "configuration_model" not in params or params["configuration_model"] is None
        ):
            raise ValueError(
                "Missing the required parameter `configuration_model` when calling `apps_update_policy_by_id_and_policyid`"
            )

        collection_formats = {}

        path_params = {}
        if "id" in params:
            path_params["id"] = params["id"]
        if "policy_id" in params:
            path_params["policyId"] = params["policy_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "configuration_model" in params:
            body_params = params["configuration_model"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Apps/{id}/Policy/{policyId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="PolicyAssociation",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class CommonModelsASMModelsApplicationUpdateModel:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "name": "str",
        "asset_group_id": "str",
        "business_impact": "str",
        "url": "str",
        "description": "str",
        "business_unit_id": "str",
        "type": "str",
        "technology": "str",
        "testing_status": "str",
        "hosts": "str",
        "collateral_damage_potential": "str",
        "target_distribution": "str",
        "confidentiality_requirement": "str",
        "integrity_requirement": "str",
        "availability_requirement": "str",
        "tester": "str",
        "business_owner": "str",
        "development_contact": "str",
        "preferred_offering_type": "str",
        "auto_delete_exceeded_scans": "bool",
    }

    attribute_map = {
        "name": "Name",
        "asset_group_id": "AssetGroupId",
        "business_impact": "BusinessImpact",
        "url": "Url",
        "description": "Description",
        "business_unit_id": "BusinessUnitId",
        "type": "Type",
        "technology": "Technology",
        "testing_status": "TestingStatus",
        "hosts": "Hosts",
        "collateral_damage_potential": "CollateralDamagePotential",
        "target_distribution": "TargetDistribution",
        "confidentiality_requirement": "ConfidentialityRequirement",
        "integrity_requirement": "IntegrityRequirement",
        "availability_requirement": "AvailabilityRequirement",
        "tester": "Tester",
        "business_owner": "BusinessOwner",
        "development_contact": "DevelopmentContact",
        "preferred_offering_type": "PreferredOfferingType",
        "auto_delete_exceeded_scans": "AutoDeleteExceededScans",
    }

    def __init__(
        self,
        name=None,
        asset_group_id=None,
        business_impact=None,
        url=None,
        description=None,
        business_unit_id=None,
        type=None,
        technology=None,
        testing_status=None,
        hosts=None,
        collateral_damage_potential=None,
        target_distribution=None,
        confidentiality_requirement=None,
        integrity_requirement=None,
        availability_requirement=None,
        tester=None,
        business_owner=None,
        development_contact=None,
        preferred_offering_type=None,
        auto_delete_exceeded_scans=None,
        _configuration=None,
    ):
        """CommonModelsASMModelsApplicationUpdateModel - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._name = None
        self._asset_group_id = None
        self._business_impact = None
        self._url = None
        self._description = None
        self._business_unit_id = None
        self._type = None
        self._technology = None
        self._testing_status = None
        self._hosts = None
        self._collateral_damage_potential = None
        self._target_distribution = None
        self._confidentiality_requirement = None
        self._integrity_requirement = None
        self._availability_requirement = None
        self._tester = None
        self._business_owner = None
        self._development_contact = None
        self._preferred_offering_type = None
        self._auto_delete_exceeded_scans = None
        self.discriminator = None

        if name is not None:
            self.name = name
        if asset_group_id is not None:
            self.asset_group_id = asset_group_id
        if business_impact is not None:
            self.business_impact = business_impact
        if url is not None:
            self.url = url
        if description is not None:
            self.description = description
        if business_unit_id is not None:
            self.business_unit_id = business_unit_id
        if type is not None:
            self.type = type
        if technology is not None:
            self.technology = technology
        if testing_status is not None:
            self.testing_status = testing_status
        if hosts is not None:
            self.hosts = hosts
        if collateral_damage_potential is not None:
            self.collateral_damage_potential = collateral_damage_potential
        if target_distribution is not None:
            self.target_distribution = target_distribution
        if confidentiality_requirement is not None:
            self.confidentiality_requirement = confidentiality_requirement
        if integrity_requirement is not None:
            self.integrity_requirement = integrity_requirement
        if availability_requirement is not None:
            self.availability_requirement = availability_requirement
        if tester is not None:
            self.tester = tester
        if business_owner is not None:
            self.business_owner = business_owner
        if development_contact is not None:
            self.development_contact = development_contact
        if preferred_offering_type is not None:
            self.preferred_offering_type = preferred_offering_type
        if auto_delete_exceeded_scans is not None:
            self.auto_delete_exceeded_scans = auto_delete_exceeded_scans

    @property
    def name(self):
        # type: () -> str
        """Gets the name of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The name of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this CommonModelsASMModelsApplicationUpdateModel.


        :param name: The name of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        if self._configuration.client_side_validation and name is not None and len(name) > 64:
            raise ValueError("Invalid value for `name`, length must be less than or equal to `64`")
        if self._configuration.client_side_validation and name is not None and len(name) < 0:
            raise ValueError(
                "Invalid value for `name`, length must be greater than or equal to `0`"
            )

        self._name = name

    @property
    def asset_group_id(self):
        # type: () -> str
        """Gets the asset_group_id of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The asset_group_id of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._asset_group_id

    @asset_group_id.setter
    def asset_group_id(self, asset_group_id):
        """Sets the asset_group_id of this CommonModelsASMModelsApplicationUpdateModel.


        :param asset_group_id: The asset_group_id of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._asset_group_id = asset_group_id

    @property
    def business_impact(self):
        # type: () -> str
        """Gets the business_impact of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The business_impact of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._business_impact

    @business_impact.setter
    def business_impact(self, business_impact):
        """Sets the business_impact of this CommonModelsASMModelsApplicationUpdateModel.


        :param business_impact: The business_impact of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        allowed_values = [
            "Unspecified",
            "Low",
            "Medium",
            "High",
            "Critical",
        ]
        if self._configuration.client_side_validation and business_impact not in allowed_values:
            raise ValueError(
                "Invalid value for `business_impact` ({}), must be one of {}".format(
                    business_impact, allowed_values
                )
            )

        self._business_impact = business_impact

    @property
    def url(self):
        # type: () -> str
        """Gets the url of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The url of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._url

    @url.setter
    def url(self, url):
        """Sets the url of this CommonModelsASMModelsApplicationUpdateModel.


        :param url: The url of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._url = url

    @property
    def description(self):
        # type: () -> str
        """Gets the description of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The description of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._description

    @description.setter
    def description(self, description):
        """Sets the description of this CommonModelsASMModelsApplicationUpdateModel.


        :param description: The description of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._description = description

    @property
    def business_unit_id(self):
        # type: () -> str
        """Gets the business_unit_id of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The business_unit_id of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._business_unit_id

    @business_unit_id.setter
    def business_unit_id(self, business_unit_id):
        """Sets the business_unit_id of this CommonModelsASMModelsApplicationUpdateModel.


        :param business_unit_id: The business_unit_id of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._business_unit_id = business_unit_id

    @property
    def type(self):
        # type: () -> str
        """Gets the type of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The type of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this CommonModelsASMModelsApplicationUpdateModel.


        :param type: The type of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._type = type

    @property
    def technology(self):
        # type: () -> str
        """Gets the technology of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The technology of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._technology

    @technology.setter
    def technology(self, technology):
        """Sets the technology of this CommonModelsASMModelsApplicationUpdateModel.


        :param technology: The technology of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._technology = technology

    @property
    def testing_status(self):
        # type: () -> str
        """Gets the testing_status of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The testing_status of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._testing_status

    @testing_status.setter
    def testing_status(self, testing_status):
        """Sets the testing_status of this CommonModelsASMModelsApplicationUpdateModel.


        :param testing_status: The testing_status of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        allowed_values = ["NotStarted", "InProgress", "Completed"]
        if self._configuration.client_side_validation and testing_status not in allowed_values:
            raise ValueError(
                "Invalid value for `testing_status` ({}), must be one of {}".format(
                    testing_status, allowed_values
                )
            )

        self._testing_status = testing_status

    @property
    def hosts(self):
        # type: () -> str
        """Gets the hosts of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The hosts of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._hosts

    @hosts.setter
    def hosts(self, hosts):
        """Sets the hosts of this CommonModelsASMModelsApplicationUpdateModel.


        :param hosts: The hosts of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._hosts = hosts

    @property
    def collateral_damage_potential(self):
        # type: () -> str
        """Gets the collateral_damage_potential of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The collateral_damage_potential of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._collateral_damage_potential

    @collateral_damage_potential.setter
    def collateral_damage_potential(self, collateral_damage_potential):
        """Sets the collateral_damage_potential of this CommonModelsASMModelsApplicationUpdateModel.


        :param collateral_damage_potential: The collateral_damage_potential of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        allowed_values = [
            "NotDefined",
            "None",
            "Low",
            "LowMedium",
            "MediumHigh",
            "High",
        ]
        if (
            self._configuration.client_side_validation
            and collateral_damage_potential not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `collateral_damage_potential` ({}), must be one of {}".format(
                    collateral_damage_potential, allowed_values
                )
            )

        self._collateral_damage_potential = collateral_damage_potential

    @property
    def target_distribution(self):
        # type: () -> str
        """Gets the target_distribution of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The target_distribution of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._target_distribution

    @target_distribution.setter
    def target_distribution(self, target_distribution):
        """Sets the target_distribution of this CommonModelsASMModelsApplicationUpdateModel.


        :param target_distribution: The target_distribution of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        allowed_values = ["NotDefined", "None", "Low", "Medium", "High"]
        if self._configuration.client_side_validation and target_distribution not in allowed_values:
            raise ValueError(
                "Invalid value for `target_distribution` ({}), must be one of {}".format(
                    target_distribution, allowed_values
                )
            )

        self._target_distribution = target_distribution

    @property
    def confidentiality_requirement(self):
        # type: () -> str
        """Gets the confidentiality_requirement of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The confidentiality_requirement of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._confidentiality_requirement

    @confidentiality_requirement.setter
    def confidentiality_requirement(self, confidentiality_requirement):
        """Sets the confidentiality_requirement of this CommonModelsASMModelsApplicationUpdateModel.


        :param confidentiality_requirement: The confidentiality_requirement of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        allowed_values = ["NotDefined", "Low", "Medium", "High"]
        if (
            self._configuration.client_side_validation
            and confidentiality_requirement not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `confidentiality_requirement` ({}), must be one of {}".format(
                    confidentiality_requirement, allowed_values
                )
            )

        self._confidentiality_requirement = confidentiality_requirement

    @property
    def integrity_requirement(self):
        # type: () -> str
        """Gets the integrity_requirement of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The integrity_requirement of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._integrity_requirement

    @integrity_requirement.setter
    def integrity_requirement(self, integrity_requirement):
        """Sets the integrity_requirement of this CommonModelsASMModelsApplicationUpdateModel.


        :param integrity_requirement: The integrity_requirement of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        allowed_values = ["NotDefined", "Low", "Medium", "High"]
        if (
            self._configuration.client_side_validation
            and integrity_requirement not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `integrity_requirement` ({}), must be one of {}".format(
                    integrity_requirement, allowed_values
                )
            )

        self._integrity_requirement = integrity_requirement

    @property
    def availability_requirement(self):
        # type: () -> str
        """Gets the availability_requirement of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The availability_requirement of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._availability_requirement

    @availability_requirement.setter
    def availability_requirement(self, availability_requirement):
        """Sets the availability_requirement of this CommonModelsASMModelsApplicationUpdateModel.


        :param availability_requirement: The availability_requirement of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        allowed_values = ["NotDefined", "Low", "Medium", "High"]
        if (
            self._configuration.client_side_validation
            and availability_requirement not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `availability_requirement` ({}), must be one of {}".format(
                    availability_requirement, allowed_values
                )
            )

        self._availability_requirement = availability_requirement

    @property
    def tester(self):
        # type: () -> str
        """Gets the tester of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The tester of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._tester

    @tester.setter
    def tester(self, tester):
        """Sets the tester of this CommonModelsASMModelsApplicationUpdateModel.


        :param tester: The tester of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._tester = tester

    @property
    def business_owner(self):
        # type: () -> str
        """Gets the business_owner of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The business_owner of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._business_owner

    @business_owner.setter
    def business_owner(self, business_owner):
        """Sets the business_owner of this CommonModelsASMModelsApplicationUpdateModel.


        :param business_owner: The business_owner of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._business_owner = business_owner

    @property
    def development_contact(self):
        # type: () -> str
        """Gets the development_contact of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The development_contact of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._development_contact

    @development_contact.setter
    def development_contact(self, development_contact):
        """Sets the development_contact of this CommonModelsASMModelsApplicationUpdateModel.


        :param development_contact: The development_contact of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """

        self._development_contact = development_contact

    @property
    def preferred_offering_type(self):
        # type: () -> str
        """Gets the preferred_offering_type of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The preferred_offering_type of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: str
        """
        return self._preferred_offering_type

    @preferred_offering_type.setter
    def preferred_offering_type(self, preferred_offering_type):
        """Sets the preferred_offering_type of this CommonModelsASMModelsApplicationUpdateModel.


        :param preferred_offering_type: The preferred_offering_type of this CommonModelsASMModelsApplicationUpdateModel.
        :type: str
        """
        allowed_values = ["None", "ScanExecution", "Applications"]
        if (
            self._configuration.client_side_validation
            and preferred_offering_type not in allowed_values
        ):
            raise ValueError(
                "Invalid value for `preferred_offering_type` ({}), must be one of {}".format(
                    preferred_offering_type, allowed_values
                )
            )

        self._preferred_offering_type = preferred_offering_type

    @property
    def auto_delete_exceeded_scans(self):
        # type: () -> bool
        """Gets the auto_delete_exceeded_scans of this CommonModelsASMModelsApplicationUpdateModel.


        :return: The auto_delete_exceeded_scans of this CommonModelsASMModelsApplicationUpdateModel.
        :rtype: bool
        """
        return self._auto_delete_exceeded_scans

    @auto_delete_exceeded_scans.setter
    def auto_delete_exceeded_scans(self, auto_delete_exceeded_scans):
        """Sets the auto_delete_exceeded_scans of this CommonModelsASMModelsApplicationUpdateModel.


        :param auto_delete_exceeded_scans: The auto_delete_exceeded_scans of this CommonModelsASMModelsApplicationUpdateModel.
        :type: bool
        """

        self._auto_delete_exceeded_scans = auto_delete_exceeded_scans

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(CommonModelsASMModelsApplicationUpdateModel, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, CommonModelsASMModelsApplicationUpdateModel):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, CommonModelsASMModelsApplicationUpdateModel):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class UserSiteCommonModelsTriageResult:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "n_provided_issues": "int",
        "n_updated_issues": "int",
        "n_inherited_issues": "int",
        "n_status_conflict_issues": "int",
    }

    attribute_map = {
        "n_provided_issues": "NProvidedIssues",
        "n_updated_issues": "NUpdatedIssues",
        "n_inherited_issues": "NInheritedIssues",
        "n_status_conflict_issues": "NStatusConflictIssues",
    }

    def __init__(
        self,
        n_provided_issues=None,
        n_updated_issues=None,
        n_inherited_issues=None,
        n_status_conflict_issues=None,
        _configuration=None,
    ):
        """UserSiteCommonModelsTriageResult - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._n_provided_issues = None
        self._n_updated_issues = None
        self._n_inherited_issues = None
        self._n_status_conflict_issues = None
        self.discriminator = None

        if n_provided_issues is not None:
            self.n_provided_issues = n_provided_issues
        if n_updated_issues is not None:
            self.n_updated_issues = n_updated_issues
        if n_inherited_issues is not None:
            self.n_inherited_issues = n_inherited_issues
        if n_status_conflict_issues is not None:
            self.n_status_conflict_issues = n_status_conflict_issues

    @property
    def n_provided_issues(self):
        # type: () -> int
        """Gets the n_provided_issues of this UserSiteCommonModelsTriageResult.


        :return: The n_provided_issues of this UserSiteCommonModelsTriageResult.
        :rtype: int
        """
        return self._n_provided_issues

    @n_provided_issues.setter
    def n_provided_issues(self, n_provided_issues):
        """Sets the n_provided_issues of this UserSiteCommonModelsTriageResult.


        :param n_provided_issues: The n_provided_issues of this UserSiteCommonModelsTriageResult.
        :type: int
        """

        self._n_provided_issues = n_provided_issues

    @property
    def n_updated_issues(self):
        # type: () -> int
        """Gets the n_updated_issues of this UserSiteCommonModelsTriageResult.


        :return: The n_updated_issues of this UserSiteCommonModelsTriageResult.
        :rtype: int
        """
        return self._n_updated_issues

    @n_updated_issues.setter
    def n_updated_issues(self, n_updated_issues):
        """Sets the n_updated_issues of this UserSiteCommonModelsTriageResult.


        :param n_updated_issues: The n_updated_issues of this UserSiteCommonModelsTriageResult.
        :type: int
        """

        self._n_updated_issues = n_updated_issues

    @property
    def n_inherited_issues(self):
        # type: () -> int
        """Gets the n_inherited_issues of this UserSiteCommonModelsTriageResult.


        :return: The n_inherited_issues of this UserSiteCommonModelsTriageResult.
        :rtype: int
        """
        return self._n_inherited_issues

    @n_inherited_issues.setter
    def n_inherited_issues(self, n_inherited_issues):
        """Sets the n_inherited_issues of this UserSiteCommonModelsTriageResult.


        :param n_inherited_issues: The n_inherited_issues of this UserSiteCommonModelsTriageResult.
        :type: int
        """

        self._n_inherited_issues = n_inherited_issues

    @property
    def n_status_conflict_issues(self):
        # type: () -> int
        """Gets the n_status_conflict_issues of this UserSiteCommonModelsTriageResult.


        :return: The n_status_conflict_issues of this UserSiteCommonModelsTriageResult.
        :rtype: int
        """
        return self._n_status_conflict_issues

    @n_status_conflict_issues.setter
    def n_status_conflict_issues(self, n_status_conflict_issues):
        """Sets the n_status_conflict_issues of this UserSiteCommonModelsTriageResult.


        :param n_status_conflict_issues: The n_status_conflict_issues of this UserSiteCommonModelsTriageResult.
        :type: int
        """

        self._n_status_conflict_issues = n_status_conflict_issues

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(UserSiteCommonModelsTriageResult, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, UserSiteCommonModelsTriageResult):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, UserSiteCommonModelsTriageResult):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import pprint
import re  # noqa: F401

from pyasoc.configuration import Configuration


class ScanManagerScanModelsPostmanCollectionFiles:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    """

    """
    Attributes:
      swagger_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    swagger_types = {
        "collection_json_file_id": "str",
        "environment_json_file_id": "str",
        "global_json_file_id": "str",
        "additional_zip_file_id": "str",
    }

    attribute_map = {
        "collection_json_file_id": "CollectionJsonFileId",
        "environment_json_file_id": "EnvironmentJsonFileId",
        "global_json_file_id": "GlobalJsonFileId",
        "additional_zip_file_id": "AdditionalZipFileId",
    }

    def __init__(
        self,
        collection_json_file_id=None,
        environment_json_file_id=None,
        global_json_file_id=None,
        additional_zip_file_id=None,
        _configuration=None,
    ):
        """ScanManagerScanModelsPostmanCollectionFiles - a model defined in Swagger"""
        if _configuration is None:
            _configuration = Configuration()
        self._configuration = _configuration

        self._collection_json_file_id = None
        self._environment_json_file_id = None
        self._global_json_file_id = None
        self._additional_zip_file_id = None
        self.discriminator = None

        if collection_json_file_id is not None:
            self.collection_json_file_id = collection_json_file_id
        if environment_json_file_id is not None:
            self.environment_json_file_id = environment_json_file_id
        if global_json_file_id is not None:
            self.global_json_file_id = global_json_file_id
        if additional_zip_file_id is not None:
            self.additional_zip_file_id = additional_zip_file_id

    @property
    def collection_json_file_id(self):
        # type: () -> str
        """Gets the collection_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :return: The collection_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :rtype: str
        """
        return self._collection_json_file_id

    @collection_json_file_id.setter
    def collection_json_file_id(self, collection_json_file_id):
        """Sets the collection_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :param collection_json_file_id: The collection_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :type: str
        """

        self._collection_json_file_id = collection_json_file_id

    @property
    def environment_json_file_id(self):
        # type: () -> str
        """Gets the environment_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :return: The environment_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :rtype: str
        """
        return self._environment_json_file_id

    @environment_json_file_id.setter
    def environment_json_file_id(self, environment_json_file_id):
        """Sets the environment_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :param environment_json_file_id: The environment_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :type: str
        """

        self._environment_json_file_id = environment_json_file_id

    @property
    def global_json_file_id(self):
        # type: () -> str
        """Gets the global_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :return: The global_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :rtype: str
        """
        return self._global_json_file_id

    @global_json_file_id.setter
    def global_json_file_id(self, global_json_file_id):
        """Sets the global_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :param global_json_file_id: The global_json_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :type: str
        """

        self._global_json_file_id = global_json_file_id

    @property
    def additional_zip_file_id(self):
        # type: () -> str
        """Gets the additional_zip_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :return: The additional_zip_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :rtype: str
        """
        return self._additional_zip_file_id

    @additional_zip_file_id.setter
    def additional_zip_file_id(self, additional_zip_file_id):
        """Sets the additional_zip_file_id of this ScanManagerScanModelsPostmanCollectionFiles.


        :param additional_zip_file_id: The additional_zip_file_id of this ScanManagerScanModelsPostmanCollectionFiles.
        :type: str
        """

        self._additional_zip_file_id = additional_zip_file_id

    def to_dict(self):
        """Returns the model properties as a dict"""
        result = {}

        for attr, _ in self.swagger_types.items():
            value = getattr(self, attr)
            if isinstance(value, list):
                result[attr] = list(
                    map(lambda x: x.to_dict() if hasattr(x, "to_dict") else x, value)
                )
            elif hasattr(value, "to_dict"):
                result[attr] = value.to_dict()
            elif isinstance(value, dict):
                result[attr] = dict(
                    map(
                        lambda item: (item[0], item[1].to_dict())
                        if hasattr(item[1], "to_dict")
                        else item,
                        value.items(),
                    )
                )
            else:
                result[attr] = value
        if issubclass(ScanManagerScanModelsPostmanCollectionFiles, dict):
            for key, value in self.items():
                result[key] = value

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ScanManagerScanModelsPostmanCollectionFiles):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ScanManagerScanModelsPostmanCollectionFiles):
            return True

        return self.to_dict() != other.to_dict()



"""
    HCL AppScan on Cloud (v2)

    This API allows you to interact with the service. The API allows you to perform many of the operations available in the UI and more.</br>For authentication, use the relevant APIs in the Account section. A successful authentication response includes a bearer token for use in subsequent API calls. Pasting this token in the 'Access token' field above will automatically add the authorization header to any API call that requires a valid session.

    OpenAPI spec version: v2

    Generated by: https://github.com/swagger-api/swagger-codegen.git
"""


import re  # noqa: F401

# python 2 and python 3 compatibility library
from pyasoc.api_client import ApiClient


class PresencesApi:
    """NOTE: This class is auto generated by the swagger code generator program.

    Do not edit the class manually.
    Ref: https://github.com/swagger-api/swagger-codegen
    """

    def __init__(self, api_client=None):
        if api_client is None:
            api_client = ApiClient()
        self.api_client = api_client

    def presences_create_presence(self, new_presence, **kwargs):
        """Create a new presence

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_create_presence(new_presence, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsNewPresence new_presence: Presence properties (required)
        :return: UserSiteCommonModelsPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.presences_create_presence_with_http_info(new_presence, **kwargs)
        else:
            (data) = self.presences_create_presence_with_http_info(new_presence, **kwargs)
            return data

    def presences_create_presence_with_http_info(self, new_presence, **kwargs):
        """Create a new presence

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_create_presence_with_http_info(new_presence, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param UserSiteCommonModelsNewPresence new_presence: Presence properties (required)
        :return: UserSiteCommonModelsPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["new_presence"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method presences_create_presence" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'new_presence' is set
        if self.api_client.client_side_validation and (
            "new_presence" not in params or params["new_presence"] is None
        ):
            raise ValueError(
                "Missing the required parameter `new_presence` when calling `presences_create_presence`"
            )

        collection_formats = {}

        path_params = {}

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "new_presence" in params:
            body_params = params["new_presence"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Presences",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsPresence",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def presences_delete_presence_by_presenceid(self, presence_id, **kwargs):
        """Delete the presence

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_delete_presence_by_presenceid(presence_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: ID of presence to be deleted (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.presences_delete_presence_by_presenceid_with_http_info(
                presence_id, **kwargs
            )
        else:
            (data) = self.presences_delete_presence_by_presenceid_with_http_info(
                presence_id, **kwargs
            )
            return data

    def presences_delete_presence_by_presenceid_with_http_info(self, presence_id, **kwargs):
        """Delete the presence

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_delete_presence_by_presenceid_with_http_info(presence_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: ID of presence to be deleted (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["presence_id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method presences_delete_presence_by_presenceid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'presence_id' is set
        if self.api_client.client_side_validation and (
            "presence_id" not in params or params["presence_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `presence_id` when calling `presences_delete_presence_by_presenceid`"
            )

        collection_formats = {}

        path_params = {}
        if "presence_id" in params:
            path_params["presenceId"] = params["presence_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Presences/{presenceId}",
            "DELETE",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def presences_download_by_presenceid_and_osflavor_and_presenceversion(
        self, presence_id, os_flavor, presence_version, **kwargs
    ):
        """Download the AppScan Presence tool. Tool includes a new generated presence key

        This API is obsolete. Please refer to API: POST /api/v2/Presences/{presenceId}/DownloadV2
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_download_by_presenceid_and_osflavor_and_presenceversion(presence_id, os_flavor, presence_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: The presenceId (required)
        :param str os_flavor: OS flavor (required)
        :param str presence_version: Presence major version (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.presences_download_by_presenceid_and_osflavor_and_presenceversion_with_http_info(
                presence_id, os_flavor, presence_version, **kwargs
            )
        else:
            (
                data
            ) = self.presences_download_by_presenceid_and_osflavor_and_presenceversion_with_http_info(
                presence_id, os_flavor, presence_version, **kwargs
            )
            return data

    def presences_download_by_presenceid_and_osflavor_and_presenceversion_with_http_info(
        self, presence_id, os_flavor, presence_version, **kwargs
    ):
        """Download the AppScan Presence tool. Tool includes a new generated presence key

        This API is obsolete. Please refer to API: POST /api/v2/Presences/{presenceId}/DownloadV2
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_download_by_presenceid_and_osflavor_and_presenceversion_with_http_info(presence_id, os_flavor, presence_version, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: The presenceId (required)
        :param str os_flavor: OS flavor (required)
        :param str presence_version: Presence major version (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["presence_id", "os_flavor", "presence_version"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method presences_download_by_presenceid_and_osflavor_and_presenceversion"
                    % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'presence_id' is set
        if self.api_client.client_side_validation and (
            "presence_id" not in params or params["presence_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `presence_id` when calling `presences_download_by_presenceid_and_osflavor_and_presenceversion`"
            )
        # verify the required parameter 'os_flavor' is set
        if self.api_client.client_side_validation and (
            "os_flavor" not in params or params["os_flavor"] is None
        ):
            raise ValueError(
                "Missing the required parameter `os_flavor` when calling `presences_download_by_presenceid_and_osflavor_and_presenceversion`"
            )
        # verify the required parameter 'presence_version' is set
        if self.api_client.client_side_validation and (
            "presence_version" not in params or params["presence_version"] is None
        ):
            raise ValueError(
                "Missing the required parameter `presence_version` when calling `presences_download_by_presenceid_and_osflavor_and_presenceversion`"
            )

        collection_formats = {}

        path_params = {}
        if "presence_id" in params:
            path_params["presenceId"] = params["presence_id"]
        if "os_flavor" in params:
            path_params["osFlavor"] = params["os_flavor"]
        if "presence_version" in params:
            path_params["presenceVersion"] = params["presence_version"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Presences/{presenceId}/Download/{osFlavor}/{presenceVersion}",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def presences_download_v2_by_presenceid(self, presence_id, platform, **kwargs):
        """Download the AppScan Presence tool. Tool includes a new generated presence key

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_download_v2_by_presenceid(presence_id, platform, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: The presenceId (required)
        :param str platform: Pss platform (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.presences_download_v2_by_presenceid_with_http_info(
                presence_id, platform, **kwargs
            )
        else:
            (data) = self.presences_download_v2_by_presenceid_with_http_info(
                presence_id, platform, **kwargs
            )
            return data

    def presences_download_v2_by_presenceid_with_http_info(self, presence_id, platform, **kwargs):
        """Download the AppScan Presence tool. Tool includes a new generated presence key

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_download_v2_by_presenceid_with_http_info(presence_id, platform, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: The presenceId (required)
        :param str platform: Pss platform (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["presence_id", "platform"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method presences_download_v2_by_presenceid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'presence_id' is set
        if self.api_client.client_side_validation and (
            "presence_id" not in params or params["presence_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `presence_id` when calling `presences_download_v2_by_presenceid`"
            )
        # verify the required parameter 'platform' is set
        if self.api_client.client_side_validation and (
            "platform" not in params or params["platform"] is None
        ):
            raise ValueError(
                "Missing the required parameter `platform` when calling `presences_download_v2_by_presenceid`"
            )

        collection_formats = {}

        path_params = {}
        if "presence_id" in params:
            path_params["presenceId"] = params["presence_id"]

        query_params = []
        if "platform" in params:
            query_params.append(("platform", params["platform"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Presences/{presenceId}/DownloadV2",
            "POST",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def presences_get_presence_by_presenceid(self, presence_id, **kwargs):
        """Get details of a presence

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_get_presence_by_presenceid(presence_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: Presence ID (required)
        :return: UserSiteCommonModelsPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.presences_get_presence_by_presenceid_with_http_info(presence_id, **kwargs)
        else:
            (data) = self.presences_get_presence_by_presenceid_with_http_info(presence_id, **kwargs)
            return data

    def presences_get_presence_by_presenceid_with_http_info(self, presence_id, **kwargs):
        """Get details of a presence

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_get_presence_by_presenceid_with_http_info(presence_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: Presence ID (required)
        :return: UserSiteCommonModelsPresence
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["presence_id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method presences_get_presence_by_presenceid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'presence_id' is set
        if self.api_client.client_side_validation and (
            "presence_id" not in params or params["presence_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `presence_id` when calling `presences_get_presence_by_presenceid`"
            )

        collection_formats = {}

        path_params = {}
        if "presence_id" in params:
            path_params["presenceId"] = params["presence_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Presences/{presenceId}",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsPresence",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def presences_get_presences(self, **kwargs):
        """Get all the Presences in the current context

        This action returns all the presences that can be accessed using the provided access token</br>OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_get_presences(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :return: list[UserSiteCommonModelsPresence]
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.presences_get_presences_with_http_info(**kwargs)
        else:
            (data) = self.presences_get_presences_with_http_info(**kwargs)
            return data

    def presences_get_presences_with_http_info(self, **kwargs):
        """Get all the Presences in the current context

        This action returns all the presences that can be accessed using the provided access token</br>OData V3 compliant
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_get_presences_with_http_info(async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param int top: The max number of records. (Up to 5000)
        :param int skip: The number of records to skip.
        :param str filter: A function that must evaluate to true for a record to be returned. (e.g. Name eq 'sam' or Name eq 'dan'). To filter an Id Property, open the model and see if its type is \"string\" or \"string($uuid)\". - For string no change is needed. - For \"string($uuid)\" add \"Guid\" immediately before the string (e.g. Id eq Guid'00000000-0000-0000-0000-000000000000')
        :param str select: Specifies a subset of properties to return.
        :param str orderby: Determines what values are used to order a collection of records. (e.g. Name,Id)
        :param str expand: Specifies the related resources to be included in line with retrieved resources.
        :return: list[UserSiteCommonModelsPresence]
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = [
            "top",
            "skip",
            "filter",
            "select",
            "orderby",
            "expand",
        ]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method presences_get_presences" % key
                )
            params[key] = val
        del params["kwargs"]

        collection_formats = {}

        path_params = {}

        query_params = []
        if "top" in params:
            query_params.append(("$top", params["top"]))
        if "skip" in params:
            query_params.append(("$skip", params["skip"]))
        if "filter" in params:
            query_params.append(("$filter", params["filter"]))
        if "select" in params:
            query_params.append(("$select", params["select"]))
        if "orderby" in params:
            query_params.append(("$orderby", params["orderby"]))
        if "expand" in params:
            query_params.append(("$expand", params["expand"]))

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Presences",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="list[UserSiteCommonModelsPresence]",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def presences_new_key_by_presenceid(self, presence_id, **kwargs):
        """Generate a new key for the given presence and return it.

        This action invalidates the previous key.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_new_key_by_presenceid(presence_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: Presence ID (required)
        :return: UserSiteCommonModelsNewKey
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.presences_new_key_by_presenceid_with_http_info(presence_id, **kwargs)
        else:
            (data) = self.presences_new_key_by_presenceid_with_http_info(presence_id, **kwargs)
            return data

    def presences_new_key_by_presenceid_with_http_info(self, presence_id, **kwargs):
        """Generate a new key for the given presence and return it.

        This action invalidates the previous key.
        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_new_key_by_presenceid_with_http_info(presence_id, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: Presence ID (required)
        :return: UserSiteCommonModelsNewKey
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["presence_id"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method presences_new_key_by_presenceid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'presence_id' is set
        if self.api_client.client_side_validation and (
            "presence_id" not in params or params["presence_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `presence_id` when calling `presences_new_key_by_presenceid`"
            )

        collection_formats = {}

        path_params = {}
        if "presence_id" in params:
            path_params["presenceId"] = params["presence_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Presences/{presenceId}/NewKey",
            "GET",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="UserSiteCommonModelsNewKey",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )

    def presences_update_presence_by_presenceid(self, presence_id, presence_data, **kwargs):
        """Modify presence data

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_update_presence_by_presenceid(presence_id, presence_data, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: ID of presence to be modified (required)
        :param UserSiteCommonModelsUpdatePresence presence_data: New presence data (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """
        kwargs["_return_http_data_only"] = True
        if kwargs.get("async_req"):
            return self.presences_update_presence_by_presenceid_with_http_info(
                presence_id, presence_data, **kwargs
            )
        else:
            (data) = self.presences_update_presence_by_presenceid_with_http_info(
                presence_id, presence_data, **kwargs
            )
            return data

    def presences_update_presence_by_presenceid_with_http_info(
        self, presence_id, presence_data, **kwargs
    ):
        """Modify presence data

        This method makes a synchronous HTTP request by default. To make an
        asynchronous HTTP request, please pass async_req=True
        >>> thread = api.presences_update_presence_by_presenceid_with_http_info(presence_id, presence_data, async_req=True)
        >>> result = thread.get()

        :param async_req bool
        :param str presence_id: ID of presence to be modified (required)
        :param UserSiteCommonModelsUpdatePresence presence_data: New presence data (required)
        :return: object
                 If the method is called asynchronously,
                 returns the request thread.
        """

        all_params = ["presence_id", "presence_data"]
        all_params.append("async_req")
        all_params.append("_return_http_data_only")
        all_params.append("_preload_content")
        all_params.append("_request_timeout")

        params = locals()
        for key, val in params["kwargs"].items():
            if key not in all_params:
                raise TypeError(
                    "Got an unexpected keyword argument '%s'"
                    " to method presences_update_presence_by_presenceid" % key
                )
            params[key] = val
        del params["kwargs"]
        # verify the required parameter 'presence_id' is set
        if self.api_client.client_side_validation and (
            "presence_id" not in params or params["presence_id"] is None
        ):
            raise ValueError(
                "Missing the required parameter `presence_id` when calling `presences_update_presence_by_presenceid`"
            )
        # verify the required parameter 'presence_data' is set
        if self.api_client.client_side_validation and (
            "presence_data" not in params or params["presence_data"] is None
        ):
            raise ValueError(
                "Missing the required parameter `presence_data` when calling `presences_update_presence_by_presenceid`"
            )

        collection_formats = {}

        path_params = {}
        if "presence_id" in params:
            path_params["presenceId"] = params["presence_id"]

        query_params = []

        header_params = {}

        form_params = []
        local_var_files = {}

        body_params = None
        if "presence_data" in params:
            body_params = params["presence_data"]
        # HTTP header `Accept`
        header_params["Accept"] = self.api_client.select_header_accept(
            ["application/json", "text/json", "text/csv"]
        )

        # HTTP header `Content-Type`
        header_params["Content-Type"] = self.api_client.select_header_content_type(
            ["application/json", "text/json", "application/x-www-form-urlencoded"]
        )

        # Authentication setting
        auth_settings = ["AccessToken"]

        return self.api_client.call_api(
            "/api/v2/Presences/{presenceId}",
            "PUT",
            path_params,
            query_params,
            header_params,
            body=body_params,
            post_params=form_params,
            files=local_var_files,
            response_type="object",
            auth_settings=auth_settings,
            async_req=params.get("async_req"),
            _return_http_data_only=params.get("_return_http_data_only"),
            _preload_content=params.get("_preload_content", True),
            _request_timeout=params.get("_request_timeout"),
            collection_formats=collection_formats,
        )
